package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H"(``#0````PP0```````#0`(``,
M`"@`&P`:``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````P!$`
M`,`1```$`````!````$`````(````"`````@``!L,0``;#$```4`````$```
M`0````!@````8````&```-!.``#03@``!``````0```!````U+T``-2]``#4
MO0``1`(``%@"```&`````!````(```#<O0``W+T``-R]```(`0``"`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&2`H```@*```("@```<`0``
M'`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DU+T``-2]``#4O0``+`(``"P"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`$\WE($\!QQYG?&')K"&CX[VNO,8!```
M`!@````%````1TY5``$``<`$````"0````(``<`$`````0````0````0````
M`0```$=.50``````!`````0`````````*P```$0````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(1```````````````10``````
M````````1@````````!'````2`````````!)`````````$L`````````````
M`$P```!-`````````$\```!0````4@````````!3````5````%4`````````
M`````````````````````%8```!7````6````%D```!:``````````````!<
M`````````%T``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````#)`0`````````````2````8@$`````````````$@```,,!````
M`````````!(```"8`@`````````````2````_P$`````````````$@```'\"
M`````````````!(```#H`0`````````````2````V@$`````````````$@``
M`#L"`````````````!(````!```````````````@````6@$`````````````
M$@```'`!`````````````!(```!V```````````````2````R@(`````````
M````$@```.\!`````````````!(````N`0`````````````2````C`$`````
M````````$@```+<!`````````````!(````0```````````````@````L`(`
M````````````$@```)T"`````````````!(```"B```````````````2````
M+```````````````(````)L``````````````!(```";`0`````````````2
M````J0``````````````$@```*("`````````````!(```#F````````````
M```6````^0``````````````$@```$X"`````````````!(````4`0``````
M```````2````NP(`````````````$@```+$``````````````!(```"4`0``
M```````````1````:0$`````````````$@```+L``````````````!(```#0
M```````````````2````CP,`````````````$@```$,!`````````````!(`
M``"\`0`````````````2````B@``````````````$0```-<`````````````
M`!(```"*`@`````````````2````>`(`````````````$@```"`"````````
M`````!(```#B`@`````````````2````X```````````````$@```'X!````
M`````````!(```":```````````````2````)0$`````````````$@```%(!
M`````````````!(````+`@`````````````2````;`(`````````````$@``
M`,(``````````````!(```"(```````````````1````/`$`````````````
M$@```)(``````````````!(```!?`@`````````````1````TP(`````````
M````$0````D!`````````````!(````L`@`````````````2````=P$`````
M````````$@```%4``````````````!(```"O`0`````````````2````A0$`
M````````````$@```&<``````````````"(```"J`0`````````````2````
M$00``!3````$````$0`7`',#````3P``_P$``!(`#@`C!```4#L``/P#```2
M``X`&P0``,`_``!%````$@`.`!D#``"0.0``-@```!(`#@!G`P``T#D``'0!
M```2``X`ZP,``!C`````````$``7`-D#```LP````````!``&`!#`P``4#\`
M`&$````2``X`)@,```!@```$````$0`0`)@#``!`3```R0```!(`#@#0`P``
M$$T``$(````2``X`"`,``%`W```0````$@`.`*0#````P````````!``%P`$
M!```8#<``"<"```2``X`\@,``/!!``#%````$@`.`+P#``!`-@``-````!(`
M#@"F`P```,`````````@`!<`W@,``,!"``!:!P``$@`.`,0#```8P```````
M`!``&`!]`P``P$$``"T````2``X`40,``(`V``#-````$@`.`+$#``!@30``
MEP$``!(`#@!B````0"```%8"```2``X`J@,``*`B```L````$@`.`"T#```@
M2@``'@(``!(`#@!&````!&````0````1`!```%]?9VUO;E]S=&%R=%]?`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N
M951A8FQE`%])3U]S=&1I;E]U<V5D`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA
M7V9I;F%L:7IE`%]?<F5G:7-T97)?871F;W)K`%]?96YV:7)O;@!S=')N8VUP
M`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P
M<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!03%]C=7)R96YT7V-O
M;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F
M;&%G<P!R96%D;&EN:P!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E
M='!V;@!M96UM;W9E`')E86QL;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R
M9'5P`'-T<G1O:P!S=')C;7``<W1R<F-H<@!S=&1E<G(`7U]V9G!R:6YT9E]C
M:&L`97AI=`!L<V5E:S8T`')E860`9V5T=6ED`&UK9&ER`%]?97)R;F]?;&]C
M871I;VX`7U]F<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`%!E
M<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L
M;V-K`%!,7V1O7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S
M90!P97)L7V1E<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?
M86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]R=6X`4$Q?;65M;W)Y7W=R87``
M7U]S=&%C:U]C:&M?9F%I;`!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R
M<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?9G!?:'<`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A
M<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET
M`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,2XS`$=,24)#7S(N,S0`1TQ)
M0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C,S`$=,24)#7S(N,RXR`$=,24)#
M7S(N,RXT`$=,24)#7S(N,0!'3$E"0U\R+C``+W5S<B]L:6(O<&5R;#4O-2XS
M."]C;W)E7W!E<FPO0T]210`````"``(``@`!``$``0`#``0``0`!``(``@`%
M``$``0`!``(``@`!``$``@`"``$`!@`$``(``0`!``$``0`!``$`!P`"``(`
M`@`"``(``0`"``(``@`!``(``0`(``(``@`&``(``@`!``$`!``"``(``@`!
M``$``0`!``(`"0`#``(`"@`"``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`"0#^`@``$`````````!S
M'VD)```*`#`$```0````M)&6!@``"0`\!```$````!1I:0T```@`1P0``!``
M```2:6D-```'`%$$```0````LY&6!@``!@!;!```$````'(9:0D```4`9@0`
M`!````!T&6D)```$`'($```0````$6EI#0```P!^!```$````!!I:0T```(`
MB`0```````#4O0``"````-B]```(````)+\```@```#\OP``"`````3````(
M````%,````@```#TO@``!@$``/B^```&`@``_+X```8#````OP``!@0```2_
M```&!0``"+\```8&```,OP``!@<``!"_```&"```%+\```8)```8OP``!@H`
M`!R_```&"P``(+\```8,```HOP``!@T``"R_```&#@``,+\```8/```TOP``
M!A```#B_```&$0``/+\```82``!`OP``!A,``$2_```&%```2+\```85``!,
MOP``!A8``%"_```&%P``5+\```88``!8OP``!AD``%R_```&&@``8+\```8;
M``!DOP``#AP``&B_```&'0``;+\```8>``!POP``!A\``'2_```&(```>+\`
M``8A``!\OP``!B(``("_```&(P``A+\```8D``"(OP``!B4``(R_```&)@``
MD+\```8G``"4OP``!B@``)B_```&*0``G+\```8J``"@OP``!BL``*2_```&
M+```J+\```8M``"LOP``!BX``+"_```&+P``M+\```8P``"XOP``!C$``+R_
M```&,@``P+\```8S``#$OP``!C0``,B_```&-0``S+\```8V``#0OP``!C@`
M`-2_```&.0``V+\```8Z``#<OP``!CL``."_```&/```Y+\```8]``#HOP``
M!CX``.R_```&0```\+\```9!``#TOP``!D(``/B_```&0P``\+X```<_````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z,<"``"!P]N>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z'D"``"!
MPXV>``!1@^PLBT$$B474BT$(B4709:$4````B47D,<"-1=!0C4744%'_DP`!
M``"+@S````"#Q`Q04/^SB````&?H<C```(N#]````(/$$(`X``^$)0$``(N#
M@````&6+`("(H@(```.+!XUP`X/`!(EUS#W___\_#X>%`0``@^P,P>`"4/^3
MY````(MUU(L_B<&)@T0!``"+!H/$$(D!C8,'H___B4$$C8,P`0``BP")00B-
M@PJC__^)00R#_P$/CE\!``")3<B-1@2-41"--+Z-M"8`````BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8/<<___QP2Y`````&H`4?]US%#_LSP!``#_DR0`
M``"#Q""%P`^$F````(/L#/^S/`$``(U]X/^3O````(GZB<:-@\.A___H/`X`
M`(/$$(7`#X2#````@^P,_[,\`0``_Y,<````@\00_Y-\````BT7D92L%%```
M``^%R@```(UE\(GP65M>7UV-8?S#_Y-@````B8,\`0``A<`/A)T```"#[`Q0
M_Y.0````BX.`````98L0@\00QH)R!0```.FK_O__@^P,_[,\`0``_Y-(````
M@\00Z5'___^+@T`!``"%P'02@^P,4&?H"BH``(/$$.EA____B?J-@WBA___H
MA0T``(F#0`$``(7`#X1&____Z]&+1>1E*P44````=2I04(V#<Z'___^S^```
M`%#_D^````"_!````.F__O__@^P,:@'_DQ0!``#HJBX``&:09I!FD&:09I`Q
M[5Z)X8/D\%!44N@8````@<,TG```:@!J`%%6_[,8`0``Z&G]___TBQPDPV:0
M9I"+'"3#9I!FD&:09I!FD&:0Z.````"!PO^;``"-BC0!``"-@C0!```YR'0=
MBX)<````A<!T$U6)Y8/L%%'_T(/$$,G#+HUT)@##C;0F`````.B@````@<*_
MFP``58GE4XV*-`$``(V"-`$``(/L!"G(B</!Z!_!^P(!V-'X=!2+DFP```"%
MTG0*@^P(4%'_TH/$$(M=_,G#+HVT)@````"058GE4^A7____@<-KFP``@^P$
M@+LT`0```'4HBX,0`0``A<!T$H/L#/^S(`$``/^3$`$``(/$$.@T____QH,T
M`0```8M=_,G#+HVT)@````#I6____XL4),-FD&:09I"055=64XG#@>Q\`0``
MB40D$(U,)"QEH10```")A"1L`0``,<`NC70F`(M4@QP/RHD4@8/``8/X$'7O
MBTPD,(MT)&"-5"0TBVPD9(M$)&B)3"0(C8PD-`$``(M<)"R)3"0,ZPJ-M@``
M``")3"0(BPJ)QXM"&(/"!#'(,?")[HG],=B+7"0(T<")0C0Y5"0,==F+="00
MBT0D+(L>BU80BVX(BWX,B50D'(V4`IEY@EJ)V(M.!,'`!8G^B6PD%`'"B>B)
M3"0,,?B)="08(<C!R0(Q^(G?`<*)Z(E\)`C!SP(QR"'8BUPD,#'HC;0>F7F"
M6HG3`<;!PP4!WHG+,?N)V(M<)#0AT,'*`C'(C9P=F7F"6HML)#@!PXGPP<`%
MC8PIF7F"6HML)#P!PXGX,=`A\,'.`C'XC;POF7F"6HML)$`!R(G9P<$%`<B)
MT3'Q(=DQT8V4*IEY@EJ+;"1$`?F)Q\''!<'+`@'YB?<QWR'',?>-M"Z9>8):
MBVPD2`'ZB<_!QP4!^HG'B=C!SP(Q^"'(P<D",=B-G"N9>8):BVPD3`'PB=;!
MQ@4!\(G.B?DQ\2'1,?F-O"^9>8):BVPD4`'9B</!PP4!V8G3B?+!RP(QVB'"
M,?*-M"Z9>8):BVPD5`'ZB<_!QP4!^HG'B=C!SP(Q^"'(P<D",=B-G"N9>8):
MBVPD6`'PB=;!Q@4!\(G.B?DQ\2'1,?F-O"^9>8):BVPD7`'9B</!PP4!V8G3
MB?+!RP(QVB'",?*-M"Z9>8):BVPD8`'ZB<_!QP4!^HG'B=C!SP(Q^"'(P<D"
M,=B-G"N9>8):BVPD9`'PB=;!Q@4!\(G.B?DQ\2'1,?F-O"^9>8):`=F)P\'#
M!0'9B=.)\L'+`C':(<+!R`(Q\HG%B=@!^HG/,>C!QP4AR,')`@'ZBWPD:#'8
MC;0^F7F"6HG7`?#!QP4!^(GO,<^)_HM\)&PAUL'*`C'NC;P[F7F"6HG#`??!
MPP6+="1P`=^)RS'3C;0UF7F"6HML)'0AP\'(`C'+C8PIF7F"6HML)'@!WHG[
MP<,%`=Z)TS'#(?LQT\'/`HV4*IEY@EH!RXGQP<$%`<N)P3'Y(?'!S@(QP0'1
MB=K!P@4!T8M4)'R-A!"AZ]ENB?HQ\C':P<L"`<*)R,'`!0'"BX0D@````(V\
M!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)(0```#!SP*-M`ZAZ]ENB=DQ^3'1
MP<H"`?&)QL'&!0'QB=:+E"2(````C9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#
MBX0DC````,'+`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,))````#!SP*-
MM`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&!0'QB=:+E"24````C9P3H>O9;HGZ,?(Q
MP@':B<O!PP4!VHG#BX0DF````,'+`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)
MSXN,))P```#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QP<H"B=:+E"2@````
MC9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#BX0DI````,'+`HV\!Z'KV6Z)\#'8
M,<@!^(G7P<<%`?B)SXN,)*@```#!SP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&
M!0'QB=:+E"2L````C9P3H>O9;HGZ,?(QP@':B<O!PP4!VHG#BX0DL````,'+
M`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)+0```#!SP*-M`ZAZ]ENB=DQ
M^3'1P<H"`?&)QL'&!0'QB=:+E"2X````C9P3H>O9;HGZ,?(QP@':B<O!PP4!
MVHG#BX0DO````,'+`HV\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,),````#!
MSP*-M`ZAZ]ENB=DQ^3'1P<H"`?&)QL'&!0'QB=:+E"3$````C9P3H>O9;HGZ
M,?(QP@':B<O!PP4!VHG#BX0DR````,'+`HG=C9P'H>O9;HGP,>@QR`'8B=/!
MR0+!PP4!V(GK"<N)WXGK(=<AR\'*`@G[B[PDS````(VT/MR\&X^)QP'SP<<%
MB<X!^XG/(=8)UR''P<@""?Z+O"30````C;P]W+P;CXG5`?>)W@G%P<8%(=W!
MRP(!]XG6(<8)[HNL)-0```"-C"G<O!N/B=V)PP'.B?D)Z\'!!2'[`<Z)P2'I
M"=F+G"38````C9P:W+P;CXGR`<O!P@7!SP(!TXGJ"?J)T8GJ(?$A^L'.`@G*
MBXPDW````(V,"-R\&X^)V`'1P<`%B?H!P0GRB?@AVB'PP<L""="+E"3@````
MC905W+P;CP'"B<C!P`4!PHGP"=B)Q8GP(<TAV`GHBZPDY````(V\+]R\&X^)
MW0'XB=?!QP4!^(G/B=G!SP()_2'Y(=4)Z8NL).@```"-M"[<O!N/`?&)QL'*
M`L'&!0'QB=:)^@GRB=6)^B'%(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':
MB<.)\,'+`@G8B<6)\"'-(=@)Z(NL)/````"-O"_<O!N/B=T!^(G7P<<%`?B)
MSXG9P<\""?TA^2'5P<H"">F+K"3T````C;0NW+P;CP'QB<;!Q@4!\8G6B?H)
M\HG5B?HAQ2'R">J+K"3X````C9PKW+P;CP':B<O!PP4!VHG#B?#!RP()V(G%
MB?`AS2'8">B+K"3\````C;POW+P;CXG=`?B)U\''!0'XB<^)V<'/`@G](?DA
MU<'*`@GIBZPD``$``(VT+MR\&X\!\8G&P<8%`?&)UHGZ"?*)U8GZ(<4A\@GJ
MBZPD!`$``(V<*]R\&X\!VHG+P<,%`=J)PXGPP<L"B=V)\PGK(>@ARPG8BYPD
M"`$``(V<']R\&X\!V(G3P<D"P<,%`=B)ZPG+B=^)ZR'7(<O!R@()^XN\)`P!
M``"-M#[<O!N/B<<!\\''!8G.`?N)SR'6"=<AQ\'(`@G^B[PD$`$``(V\/=R\
M&X\!_HG?P<<%`?Z)UPG'B?V)UR'=(<?!RP()[XNL)!0!``"-C"G<O!N/`?F)
M]\''!0'YB<<)WXG]B<<A]2'?">^+K"08`0``C90JW+P;CXML)`@!^HG/P<X"
MP<<%`?J+O"0<`0``C80XUL%BRHG?,?<QS\')`@''B=#!P`4!QXN$)"`!``"-
MG`/6P6+*B?`QR#'0`=B)^\'#!0'8B=.+E"0D`0``P<L"C906UL%BRHG.,=XQ
M_L'/`@'6B<+!P@4!UHN4)"@!``"-C!'6P6+*B=HQ^C'"P<@"`<J)\<'!!0'*
MB<&+A"0L`0``C80#UL%BRHG[,<LQ\P'#B=#!P`4!PXN$)#`!``#!S@*-O`?6
MP6+*B<@Q\#'0`?B)W\''!0'XB=>+E"0T`0``P<\"C901UL%BRHGQ,?DQV<'+
M`@'1B<+!P@4!T8N4)#@!``"-M!;6P6+*B?HQVC'"P<@"`?*)SL'&!0'RB<:+
MA"0\`0``C80'UL%BRHG?,?<QS\')`@''B=#!P`4!QXN$)$`!``"-G`/6P6+*
MB?`QR#'0`=B)^\'#!0'8B=.+E"1$`0``P<L"C906UL%BRHG.,=XQ_L'/`@'6
MB<+!P@4!UHN4)$@!``"-C!'6P6+*B=HQ^C'"P<@"`<J)\<'!!0'*B<&+A"1,
M`0``C80#UL%BRHG[,<LQ\\'.`@'#B=#!P`4!PXN$)%`!``"-O`?6P6+*B<@Q
M\#'0`?B)W\''!0'XB=>+E"14`0``P<\"C901UL%BRHGQ,?DQV<'+`@'1B<+!
MP@4!T8N4)%@!``"-M!;6P6+*B?HQVC'"`?*)SL'(`L'&!0'RB<:+A"1<`0``
MC80'UL%BRHG?,?<QS\')`@''B=#!P`4!QXN$)&`!``"-G`/6P6+*B?`QR#'0
MP<H"`=B)^\'#!0'8BYPD9`$``(VT'M;!8LJ)RS'3,?O!SP(!\XG&P<8%`?.+
MM"1H`0``C;0UUL%BRHG=`<Z)T<'%!3'Y,<'!R`(!\8MT)!"-+"F+3"0,9@]N
MQ8ML)!0!RXT,*(M$)!AF#V[;9@]NR68/8L.-##AF#V[19@]BRF8/;,$/$0:+
M1"0<`=")1A"+A"1L`0``92L%%````'4+@<1\`0``6UY?7</H=2$``"Z-="8`
M5>@Q(0``@<4.CP``5U93@^P<B50D"(7`#X2R````B<&+A;0```"+$(72#X2@
M````#[8!A,!T!#P]=54Q_XL:A=MT/8E4)`R)V(G3B4PD!(G&C;0F`````(/L
M!%?_="0,5O^5\````(/$$(7`=0:`/#X]=#2+<P2#PP2%]G7:B?.#Q!R)V%M>
M7UW#C;8`````B<\/MD<!@\<!A,!T!#P]=?$IS^N8C78`BU0D#(GPB=Z)PXM$
M)`@IUHU<.P'!_@*),(/$'(G86UY?7<,NC70F`(/$'#';B=A;7E]=PXUT)@!6
MZ$D@``"!QBZ.``!3B<.#['QEH10```")1"1T,<"-1"044%/_EM0```"#Q!"%
MP'4WBU0D'('B`/```('Z`$```'0(@?H`H```=1^#[`AJ`E/_EF@```"#Q!"%
MP`^4P`^VP.L&C70F`#'`BU0D;&4K%10```!U!H/$=%M>P^@.(```+HVT)@``
M``"-M@````!55U;HMQ\``('&G(T``%.)PX'LC````&6A%````(E$)'PQP(7;
M=`6`.P!U)(M$)'QE*P44````#X4\`0``@<2,````6UY?7<,NC;0F`````(/L
M#%/_EG@```")QX/$$(7`=,F#[`Q7_Y:4````@\00A<`/A+@```"`>!,NC5`3
M=0^`>@$`=-PNC;0F`````)"`>!,N#X2V````B50D#(/L#%/_EJ````"+5"0<
MB<6)%"2)5"0<_Y:@````C40%`HD$)/^6P````(G%6(V&)*'__UJ+5"044E-0
M:O]J`57_EN@```"#Q!B-1"0D4%7_EG````"#Q!"#^/]T$(M$)"PE`/```#T`
M0```=&6#[`Q5_Y:D````@\00@^P,5?^69````(/$$.DY____C;8`````@^P,
M5_^6N````(D<)/^6S````(/$$.GA_O__+HUT)@"`>@$N#X5`____@'H"``^$
M__[__^DQ____C;0F`````(GHZ(G^___KG^B"'@``9I!64^@)\/__@<,=C```
M@^P$C8.`X?__B[.`````4(V#*J'___^SA````%!E_S;_D_P```!8C8/DHO__
M6FH`4%"-@T:A____LT````!09?\V_Y.,````@\0D6U[#+HUT)@!55U93@>P`
M$```@PPD`(/L,.C-'0``@<>NBP``B50D$(G&9:$4````B80D(!```#'`:/\/
M``"-AUNA__^-;"0D55#_E]@```"#Q!"%P'X0B<.-0/^`?!P;`'5%A<!U.8N'
M@````(/L!/]T)!!69?\P_Y=0````@\00BX0D'!```&4K!10```!U0H'$+!``
M`%M>7UW#C70F`(G#C;8`````@^P$4VHO5?^7[````(/$$(7`=*N+AX````!3
M559E_S#_EZP```"#Q!#KKNA0'0``5>@1'0``@<7NB@``5XG'5E.)TX/L.&6A
M%````(E$)"@QP#'`@#H]#Y3``<-3_Y6@````@\00B40D!(GXC50D&.B;^___
MA<`/A!,!``"#[`R)QE#_E:````"+3"04@\00.<@/@]@```"+1"08P>`"B40D
M"(N%M````(D$)`^V!X3`#X2I`0``/#T/A*$!``")^(VT)@`````/ME`!@\`!
MA-)T!8#Z/77P*?B+#"2+="0(@^P,BU0D$`,QC400`E#_E<````")!H/$$(7`
M=%&+#"2+="0(BP&-3P&+%#`/M@>(`CP]=!V$P'4*ZQ>-="8`/#UT#P^V`8/"
M`8/!`8@"A,!U[<8"/3'`+HVT)@`````/M@P#B$P"`8/``83)=?&+1"0<92L%
M%`````^%$P$``(/$+%M>7UW#+HVT)@`````QP(VV``````^V%`.(%`:#P`&$
MTG7RZ\<NC;0F`````(N%M````(L0B00DBS*%]@^$P@```#'V+HVT)@````"0
MB?"#Q@&+#+*%R77TC02%#````(N-.`$``(7)=6.)5"0,@^P,4,>%.`$```$`
M``#_E<````")P8/$$(7`#X1=____C02U`````(/L!(E$)`Q0BU0D%%)1B4PD
M'/^5W````(M$)!"+3"0<@\00B0C'1+$$`````(ET)!CI??[__Y"#[`A04O^5
M.````(G!BT0D$(/$$(D(A<D/A`'___^-!+4`````B40D".O#+HUT)@`QP.ES
M_O__N`@````Q]NE0____Z`@;```NC;0F`````.CT&@``!9^(``"#[`R-D(#A
M__]2C9`JH?___["$````4HN0@````&7_,O^0_````(/$',,NC;0F`````(UT
M)@!55U93@>P`$```@PPD`('L`!```(,,)`"#[!PQ[>@N[/__@<-"B```9:$4
M````B80D#"```#'`_Y,4````@^P(C9-FH?__4E"-@VJA__]0:`$0``!J`8VT
M)"<0``!6_Y/H````@\0<:``0``"-?"025U;_D]@```"#Q!"%P'@L@^P,B<:-
M0`%0_Y/`````B<6#Q!"%P'04@^P$5E=0_Y.<````QD0U``"#Q!"+A"0,(```
M92L%%````'4-@<0<(```B>A;7E]=P^CS&0``C78`Z.09```%CX<``.DA____
MD%575E.![``0``"##"0`@>R<````Z%?K__^!PVN'``"+O"2P$```BZPDM!``
M`&6A%````(F$)(P0```QP(U$)"R)1"04B<*-@WBA___H'_C__X/L"&HOB<97
M_Y,\````@\00A<!T,HV#@:'__XGZZ!W\__^)^(N4)(P0``!E*Q44````#X69
M`0``@<2<$```6UY?7<.-="8`@^P,5?^3!`$``%I9C8N.H?__B4PD%%%0_Y/0
M````C8N0H?__B<6-@YFB__^#Q!")1"08A>UTEX!]``")3"0<#X3J````C78`
MA?9T%H/L"%56_Y,,`0``@\00A<`/A*<```"#[`Q5_Y.@````B<*-1`7_@\00
M.<5R$>LC+HUT)@#&``"#Z`$YQ70%@#@O=/&#[`Q5_Y.@````B<*#Q!")5"00
M@^P,5_^3H````(M4)""-1`(!@\00/?\/```/APS___^#[`17_W0D)%7_="0H
M:``0``!J`8VL)*@```!5_Y/H````@\08_W0D'%7_DW````"#Q!"%P'40BT0D
M/"4`\```/0"```!T3X/L"/]T)!1J`/^3T````(G%@\00A<`/A*G^__^`?0``
M#X49____A?9T!8`^+G00N@$```"-JW:A___I5O___X!^`0!TN^OH+HVT)@``
M``"#[`AJ`57_DV@```"#Q!"%P'6>B>J-@X&A___H@/K__X/L#%7_DP0!``"#
MQ!#I4_[__^BY%P``+HVT)@````"05NAI%P``@<9.A0``4X/L#(M<)!AJ+U/_
MEE0```"%P(U0`8GP#T7:B5PD((/$%%M>_Z`$`0``+HVT)@````!FD%575E.!
M[``0``"##"0`@^P<Z"$7``"!Q?Z$``"+M"0P$```9:$4````B80D#!```#'`
MA?8/A*8```"`/@`/A)T```"#[`Q6_Y6@````C4@!@\00@?D`$```#X?A````
MC5PD#(/Y!`^#I````(7)#X7<````C40#_SG#<@[K$6:0Q@``@^@!.=AT!8`X
M+W3Q@^P(:B]3_Y54````@\00A<!T/CG##X*&````@^P,4_^5!`$``(/$$(N4
M)`P0``!E*Q44````#X6D````@<0<$```6UY?7<,NC;0F`````&:0BX0D#!``
M`&4K!10```!U?XV%=J'__XF$)#`0``"!Q!P0``")Z%M>7UW_H`0!``"0BU0.
M_(G?B50,"(G!P>D"\Z7I3O___RZ-M"8`````9I#&``#I<O___RZ-M"8`````
M,<#I</___RZ-M"8`````D`^V%HA4)`SVP0(/A!3___\/MU0._F:)5`P*Z07_
M___H_!4``"Z-M"8`````C70F`%575NBG%0``@<:,@P``4X/L+&6A%````(E$
M)!PQP(U<)!B+KK0```"-OI*A__^)VHGXZ$GT__^%P'0NBU0D&(M%`(T$D(M0
M!(D0A=)TX&:0BU`(@\`$B1"%TG7TB=J)^.@;]/__A<!UTHNNM````(V^FZ'_
M_XG:B?CH`O3__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%
MTG7TB=J)^.C3\___A<!UT8NNM````(V^HZ'__XG:B?CHNO/__X7`="^+5"08
MBT4`C020BU`$B1"%TG3@C78`BU`(@\`$B1"%TG7TB=J)^.B+\___A<!UT8NN
MM````(V^K*'__XG:B?CH<O/__X7`="^+5"08BT4`C020BU`$B1"%TG3@C78`
MBU`(@\`$B1"%TG7TB=J)^.A#\___A<!UT8V&LZ'__XN^M````(D$)(L$)(G:
MZ";S__^%P'0LBU0D&(L'C020BU`$B1"%TG3@BU`(@\`$B1"%TG7TBP0DB=KH
M^O+__X7`==2+KK0```"-OL.A__^)VHGXZ.'R__^%P'0VBU0D&(M%`(T$D(M0
M!(D0A=)TX"Z-M"8`````9I"+4`B#P`2)$(72=?2)VHGXZ*OR__^%P'7*C89X
MH?__B[ZT````B40D!(M$)`2)VNB,\O__A<!T,XM4)!B+!XT$D(M0!(D0A=)T
MWXVV`````(M0"(/`!(D0A=)U](M$)`2)VNA9\O__A<!US8V&SZ'__XN^M```
M`(E$)`R+1"0,B=KH.O+__X7`=#&+5"08BP>-!)"+4`2)$(72=-^-="8`BU`(
M@\`$B1"%TG7TBT0D#(G:Z`GR__^%P'7/C8;9H?__B[ZT````B40D"(M$)`B)
MVNCJ\?__A<!T,8M4)!B+!XT$D(M0!(D0A=)TWXUT)@"+4`B#P`2)$(72=?2+
M1"0(B=KHN?'__X7`=<^+KK0```"-ON.A__^)VHGXZ*#Q__^%P'0UBU0D&(M%
M`(T$D(M0!(D0A=)TX"Z-M"8`````D(M0"(/`!(D0A=)U](G:B?CH:_'__X7`
M=<N+KK0```"-OH&A__^)VHGXZ%+Q__^%P'0OBU0D&(M%`(T$D(M0!(D0A=)T
MX(UV`(M0"(/`!(D0A=)U](G:B?CH(_'__X7`==&)VHV&[:'__^@2\?__A<!T
M"XG"BT0D".@C]?__B=J-AOZA___H]O#__X7`=`V)PHV&$*+__^@%]?__B=J-
MAANB___HV/#__XG"A<!T*XM$)`3HZ?3__XM$)!QE*P44````=3.+!"2#Q"R-
MECRB__];7E]=Z<?T__^)VHV&*Z+__^B:\/__A<!TS8G"BT0D#.BK]/__Z\#H
M]!$``(UT)@#HY!$```6/?P``@^P<98L5%````(E4)`PQTHU4)`B-@,^A___H
M5_#__X7`="L/MA"`^C`/E,"$T@^4P@G0@_`!#[;`BU0D#&4K%10```!U#(/$
M',.-="8`,<#KY^B/$0``+HVT)@````"-M"8`````4^@*X___@<,>?P``@^P8
M9:$4````B40D##'`C40D)(E$)`A0BX.8````_W0D)&H!_S#_DW0```#'!"3_
M````_Y,4`0``+HVT)@````"-=@!55U93C9PD``#__X'L`!```(,,)``YW'7R
M@^PLZ)_B__^!P[-^``")Q66A%````(F$)!P``0`QP&H":@!J`%7_DP@!``"#
MP/^#TO^)1"08BW0D&(G7B50D','_'S'X*?@QTB7__P``,?HQ^"GX&?J+?"0<
M*<:)="08&=>)?"0<@\00C70D%(7_#XC"````9I!J`/]T)!#_="005?^3"`$`
M`"'0@\00@_C_#X3-````@^P$:`@``0!65?^36````(/$$(/X_P^$D0```(/X
M!W98C40&^#GP<E"-/20!``#K!X/H`3GP<D&+$(M(!#,4'S-,'P0)RG7I*?"9
M`T0D"!-4)`R+C"0<``$`92L-%`````^%A@```('$+``!`%M>7UW#C;0F````
M`(%$)`@``/__BU0D"(-4)`S_BTPD#(G0B<HU``#___?2"=`/A4#___^X____
M_[K_____ZZ:+A"0<``$`92L%%````'4P@^P,C8-+HO__4&?H-/[__XN$)!P`
M`0!E*P44````=1"#[`R-@SZB__]09^@4_O__Z(\/```NC;0F`````(VT)@``
M``!3Z`KA__^!PQY]``"#[`C_D[````"#[`Q0_Y.H````@\00A<!T`HL`@\0(
M6\.-=@!5Z!$/``"!Q>Y\``!75E.#["QEH10```")1"0<,<"-M5>B__^-5"08
MBWPD0(GPZ*WM__^%P'0'@#@`B<-U(HM$)!QE*P44````=76)^H/$+(GP6UY?
M7>FE\?__+HUT)@"#[`Q7_Y6@````B40D'(D<)/^5H````(M4)!R-1`("B00D
M_Y7`````@\0,B<*-A8ZA__]34(V%F:+__U=0:O]J`5*)5"0L_Y7H````@\0@
MBU0D#(M$)!QE*P44````=(WHBPX``"Z-M"8`````C78`55=64^@'X/__@<,;
M?```@>P,`0``BX0D(`$``(U\)"B)^HE$)`R-BVZB__]F#V[!C8LFHO__9:$4
M````B80D_````#'`C8-VH?__9@]NR8V+":+__\>$)*@`````````9@]NT(V#
M>Z+__V8/8L)F#V[8C8-SHO__QX0DQ`````````!F#V[@9@]BRV8/UH0DH```
M`&8/;L%F#V+$C8.$HO__C8M_HO__QX0DF`````````!F#VS!9@]NZ(V#>*'_
M_P\1A"2T````9@]NP68/8L6)1"089@_6A"20````Z"WL__^%P'0+@#@`B<8/
MA88$``#_D[````"#[`Q0_Y.H````@\00A<`/A-,#``"+*(7M#X3)`P``@^P,
M5?^3H````(U$``&#Q!"#[`Q0_Y/`````B<8/MD4`@\00B70D"(3`=#V-BXVB
M__^)?"0$B?>)SHVT)@````"#[`P/ML"#Q0%05FK_:@%7@\<"_Y/H````#[9%
M`(/$((3`==R+?"0$C;0DL````(V#$*+__^L+D(M&!(/&!(7`=#:)^NAOZ___
MB<6%P'3I@#@`=.3H/^S__X7`=-N#[`Q5_Y,$`0``B<6#Q!"%P'4X+HVT)@``
M``"-M"2@````BRZ%[70C@'T```^$\0(``(GHZ`+L__^%P`^%\@```(MN!(/&
M!(7M==V#[`Q5_Y.@````6O]T)!2)QO^3H````(VT!@0$``")-"3_D\````")
M1"04B<&-@Y*B____="084(V#D*'__XE$)"!0C8.7HO__58G-4&K_:@%1_Y/H
M````@\0H:,`!``!5_Y,8````@\00@_C_=1'_DQ````"+`(/X$0^%V`(``(/L
M"%?_="00_Y/4````B<6#Q!"%P'1Y@^P,_W0D$(M$)!S_,(V#3*/__U`Q]HN#
MF````&H!_S#_DRP```"#Q""+A"3\````92L%%`````^%800``('$#`$``(GP
M6UY?7<.-M"8`````@^P,@\8$5?^3!`$``(G%@\00A<`/A-7^___I^?[__RZ-
MM"8`````D(M$)#@E`/```#T`0```#X5S____BT0D0(E$)!#_D[`````Y1"00
M#X5;____BT0D."7_`0``/<`!```/A4?___^#[`Q6_Y/`````B?J)QHV#8J+_
M_^BGZ?__@\00A<`/A$0"``"#[`A0BT0D&/\P9^@<\?__B40D((/$$(7`#X0E
M`@``@^P,_W0D'/^3H````(G"@\00@_@#=D:#[`B-@Z"B__]0BT0D'(U$$/R)
M5"0H4/^3#`$``(/$$(7`=2*+5"0<@_H$#X0!`P``BT0D$(!\$/LO#X3R`@``
MC;8`````B?J-N\^A__^)^.@1Z?__A<`/A,D!```/M@"$P`^$O@$``#PP#X2V
M`0``C9,\HO__B?B-N^2B___H`^W___^3%````%=0C8/$HO___W0D$/]T)!!0
M:O]J`5;_D^@```"-@]*B__^#Q"")1"0,ZS9FD/^3$````(,X$75`_Y,4````
M@\4!@^P,5U50_W0D(/]T)"#_="0L:O]J`5;_D^@```"#Q#"#[`AHP`$``%;_
MDQ@```"#Q!"#^/]TM8/L#/]T)!#_DV0```"+1"0HB?+H;>S__XDT)&?H9/K_
M_X/$$.GL_?__C70F`#'MZ2']__^0BX0DD````(VT))````"%P'0@C;8`````
MB?KH$>C__X7`=`6`.`!U.(M&!(/&!(7`=>:#[`R-JV>B__]J#?^3P````(G&
M@\00B40D"+A3````Z0W\__\NC;0F`````&:0@^P,4/^3!`$``(G%@\00A<!T
MM>F_^___@^P(4/]T)!"+1"0<_S"-@Q"C___I.?W__XVT)@````"#[`Q09^BN
M^?__@\00BX0D_````&4K!10````/A9P!``")M"0@`0``@<0,`0``B=A;7E]=
M_Z`$`0``C;8`````BT0D#(L`B40D$.G,_?__+HVT)@````"0@^P(:@#_="0<
M_Y,H````@\00A<`/A##^__^)1"0,Z%WW__^)1"00B50D%(72#X@7_O__@\#V
M:@"#TO]24(M,)!A1B4PD'/^3"`$``(/$#&H&C80DD@```%"+3"0848E,)!S_
MDU@```"#Q!"+3"0,@_@&#X7R````@;PDB@````!#04,/A<']__]F@;PDC@``
M`$A%#X6Q_?__:@"+1"04BU0D&(/`SH/2_U)048E,)!S_DP@!``"#Q`QJ*(V\
M)-L```!7BTPD&%'_DU@```"#Q!"#^"@/A9````"-@^2B___&A"3[`````%"-
M@[6B__]7_W0D$/]T)!!0:O]J`5;_D^@```"#Q"#IS_W__XM$)`R+4`2%T@^$
M!?W__X/L#%*)5"0<_Y.@````@\00@_@##X;K_/__@^P(C8NEHO__48M4)!B-
M1`+\4/^3#`$``(M4)!R#Q!"%P`]%5"00B50D$.F[_/__Z$8'``"+A"3\````
M92L%%````'7K@^P,C8.JHO__4&?HIO7__XVV`````%575E/HI]C__X'#NW0`
M`(/L'&6A%````(E$)`PQP(U\)`B)^HNS@````&6++@^V162(166-@[.A___H
M<>7__X7`=`F`.#$/A&0!``!GZ-[P__]EBRZ-@^.B__]J`VH!4%7_DTP```")
MQ8/$$(7`="J#[`2-@^6B__]0BT4,_S!E_S;_DU````"+10R+`(/$$/9`"D`/
MA48!``"-@^JB__]J`VH!4&7_-O^33````(G%@\00A<!T*HGZC8.!H?__Z.SD
M__^%P`^$]````(/L!%"+10S_,&7_-O^34````(/$$(/L!(V#[*+__VH!4&7_
M-O^3(````(V3`:/__X/$#%)09?\V_Y-0````98L&B?K&0&4`C8-XH?__Z)+D
M__^#Q!")@T`!``")QH7`=$.#[`AHP`$``%;_DQ@```"-4`&#Q!"#^@%V"8/X
M$0^%I0```(M$)`QE*P44````#X6X````@\0<6UY?7<.-M"8`````@^P,_[-$
M`0``9^@A]___B8-``0``B<:#Q!"%P'6?BT0D#&4K!10```!U?H/L#(V#H*/_
M_U#_D^`````NC70F`(!X`0`/A)O^___IC?[__Y"+@T0!``"+$(M%#(L`Z"[G
M___I"O___RZ-M"8`````D(/L"%!E_S;_D\0```"#Q!#II?[__XM4)`QE*Q44
M````=1=0BX-$`0``5O\PC8/$H___4/^3X````.@"!0``9I!75E/HB-;__X'#
MG'(``(/L$&6A%````(E$)`PQP(U4)`B+="0@C8//H?__Z&#C__^%P'0;#[80
M@/HP#Y3`A-(/E,((T'4)A?9T!8`^`'49BT0D#&4K!10```!U:(/$$%M>7\,N
MC70F`(/L#%9GZ![M__^)QUA::B]7_Y-4````A<"-4`$/1?J)/"3_DP0!``"#
MQ`R-DY*B__]J!%)0_Y/P````@\00A<!UI8M$)`QE*P44````=0V#Q!")\%M>
M7^D\Y/__Z#<$``"-M"8`````4^BZU?__@</.<0``@^P4:F#_D\````!F#V^#
MC.'__[GPX=+#,=N)2!")6!3'0!@`````QT!<``````\1`(/$&%O#+HVT)@``
M``"-M@````!55U;HEP,``('&?'$``%.#[!R+7"0PBT0D.(M\)#3!X`,#0Q2+
M2QB-:QR)0Q2+1"0X@]$`P>@=`<B)0QB+0UR%P`^%^0```(-\)#@_#XX^`0``
MBT0D.(/H0(E$)`S!Z`:-<`&)1"0(P>8&`?Z-="8`\P]O!XG8@\=`#Q%%`/,/
M;T_0#Q%-$/,/;U?@#Q%5(/,/;U_P#Q%=,.C3U?__.?=USXM$)`B+5"0,P>`&
M*<*)5"0X@WPD.`1R5XL&B>F)0QR+1"0XBU0D.(M$!OR)1!7\C4,@@^#\*<$I
MS@-,)#B#X?R#^01R$H/A_#'2BRP6B2P0@\($.<IR\XM$)#B)0UR#Q!Q;7E]=
MPRZ-M"8`````D(M$)#B%P'3@#[8&B$,<]D0D.`)TTXM$)#B+3"0X#[=$!OYF
MB40-_NN_C;0F`````+I`````*<([5"0X#T]4)#B#[`0!Z%*)5"005U#_EIP`
M``"+5"08BT-<`="#Q!")0UR#^$!UB8G8*50D.`'7Z.W4___IO_[__RZ-M"8`
M````B?[I&____RZ-M"8`````D%575NCW`0``@<;<;P``4X/L'(M<)#2+?"0P
MBVL8BTL4#\V)Z(G-B00DB<@/S<'H`XEL)`2-:QR#X#^-4`'&1`,<@(/Z.`^.
M]0```+A`````C4P5`"G0="(QTJ@!=`RZ`0```,8!`#G"<Q#&!!$`QD01`0"#
MP@(YPG+PB=CH3]3__V8/[\`/$4,<#Q%%(`\111`/$44H\P]^#"2)V&8/UDM4
MZ"K4__^+`\'H&(@'BP/!Z!"(1P&+`XAG`HL#B$<##[9#!XA'!`^W0P:(1P6+
M0P2(9P:+0P2(1P</MD,+B$<(#[=#"HA'"8M#"(AG"HM#"(A'"P^V0P^(1PP/
MMT,.B$<-BT,,B&<.BT,,B$</#[9#$XA'$`^W0Q*(1Q&+0Q"(9Q*+0Q"(1Q.)
M\(E<)#"#Q!Q;7E]=_Z!D````C;8`````N#@```"-3!4`*="#^`0/@HP```"-
M403'`0````"#XOS'1`'\`````"G1`<B#X/R#^`0/@AW___^)P8UH_X/A_,'M
M`HE,)`RY!````(/E`<<"`````#G!#X/X_O__A>UT&,="!`````"+1"0,N0@`
M```YP0^#W/[__XM$)`S'!`H`````QT0*!`````"#P0@YP7+JZ;W^__\NC;0F
M`````(7`#X2M_O__Q@$`J`(/A*+^__\QTF:)5`'^Z9;^__^+-"3#BSPDPXLL
M),-FD&:0D.@D````!<]M``"#[`S_L"`!``#_="0<_W0D'/]T)!S_D$0```"#
MQ!S#BP0DPV:0D%9>Z/+___\%G6T``(/L#/^0R````````%.#[`CH;]'__X'#
M@VT``(/$"%O#````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V
M,P`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!(T5GB:O-[_[<NIAV
M5#(0`1L#.Q@!```B````H'___V`!``#`?___P`P``"""__\T`0``4(/__X0!
M``!0C___R`$``#"0__]``@``P)#__XP"``!`DO__0`,``*"2__^0`P``<)/_
M_R`$``#`E?__H`0```"6___$!```T);__UP%``#@EO__<`4``!"9__]P!@``
M4)G__Z`&``#0FO__)`<``-">__]D!P``0)___X`'``"0G___J`<``$"A__]<
M"```<*'__X@(``!`HO__Z`@``*"I__^$"P``P*O__U0,``"0K/__"`T``."L
M__\L#0``@*[__WP-``!_L/__O`T``(.P___0#0``A[#__^0-``"0L/__^`T`
M`+FP__\<#@``P+#__S`.```4``````````%Z4@`!?`@!&PP$!(@!!P@0````
M'````.2`__\L`````````!0``````````7I2``%\"`$;#`0$B`$``"`````<
M````.'[__R``````#@A&#@Q*#PMT!'@`/QH[*C(D(D````!`````Q('___L+
M````00X(A0)!#@R'`T$.$(8$00X4@P5(#I`#`^4+"@X40<,.$$'&#@Q!QPX(
M0<4.!$$+````=````(0```"`C?__W`````!!#@B%`DP.#(<#00X0A@1!#A2#
M!4,.,`))#C1!#CA$#CQ!#D!)#C!9"@X40\,.$$'&#@Q!QPX(0<4.!$<+=`H.
M%$/##A!!Q@X,0<<."$'%#@1&"T,.%$7##A!!Q@X,0<<."$'%#@0`2````/P`
M``#HC?__@@````!!#@B&`DP.#(,#10Z(`5$.C`%!#I`!20Z``6$.B`%"#HP!
M00Z0`4D.@`%@"@X,0<,."$'&#@1!"P```+````!(`0``+([__WX!````00X(
MA0)!#@R'`T$.$(8$3`X4@P5(#J`!;`H.%$'##A!!Q@X,0<<."$'%#@1)"T,.
MK`%!#K`!2PZ@`4<.K`%!#K`!20Z@`7$.K`%!#K`!:0ZL`4<.J`%%#JP!00ZP
M`4$.M`%"#K@!0@Z\`4$.P`%)#J@!10ZL`4$.L`%)#J`!6`ZL`4$.L`%)#J`!
M0PZL`4$.L`%)#J`!3@ZL`4$.L`%2#J`!`$P```#\`0``^([__UL`````00X(
MA@)!#@R#`TX.$$T.%$P.&$$.'$,.($<.'$<.&$(.'$$.($$.)$P.*$$.+$,.
M,$D.#$'##@A!Q@X$````C````$P"```(C___T`````!!#@B%`D$.#(<#00X0
MA@1!#A2#!48.E"!'#L0@90[(($L.S"!!#M`@20[`(%T.Q"!$#L@@00[,($,.
MT"!)#L`@5@H.%$'##A!!Q@X,0<<."$'%#@1%"TL.Q"!!#L@@0@[,($$.T"!)
M#L`@2P[$($$.R"!!#LP@0P[0($D.P"``?````-P"``!(C___2`(```!!#@B%
M`DP.#(<#0PX0A@1!#A2#!44.3%<.4$D.0%H.3$,.4$T.0`)4#DQ+#E!+#D`"
M:0H.%$'##A!!Q@X,0<<."$'%#@1)"P)D#DQ!#E!5#D!2#D1%#DA%#DQ!#E!5
M#D!7#DA!#DQ!#E!/#D`````@````7`,``!B1__\T`````$T.$$<.%$P.&$$.
M'$D.($D.!`"4````@`,``#21___-`````$$."(4"00X,AP-!#A"&!$$.%(,%
M1@Z4($H.E$!'#K!`90ZX0$<.O$!!#L!`1P[$0$4.R$!"#LQ`2`[00$D.M$!%
M#KA`10Z\0$$.P$!)#K!`1PZ\0$8.P$!+#K!`1PZT0$$.N$!!#KQ`00[`0$X.
ML$!6"@X40\,.$$'&#@Q!QPX(0<4.!$$+`!`````8!```;)'__Q``````````
M_````"P$``!HD?__)P(```!!#@B%`D$.#(<#00X0A@1!#A2#!48.E"!*#K`A
M`D`.N"%"#KPA0P[`(4D.L"%M"@X40<,.$$'&#@Q!QPX(0<4.!$4+0PZ\(4$.
MP"%'#KPA00ZX(4L.O"%!#L`A5PZP(6`.N"%!#KPA00[`(4D.L"%+#KPA00[`
M(4\.L"%=#KPA00[`(4L.L"%'#KPA00[`(5$.L"%.#K0A00ZX(40.O"%!#L`A
M1`[$(44.R"%"#LPA2`[0(4D.N"%$#KPA00[`(4D.L"%7#K@A1`Z\(4(.P"%+
M#K`A?@ZX(4(.O"%!#L`A20ZP(50.O"%!#L`A20ZP(2P````L!0``F)+__S8`
M````00X(A@),#@R#`T,.&$8.'$$.(%<.#$'##@A!Q@X$`(````!<!0``J)+_
M_W0!````00X(A0)!#@R'`T$.$(8$00X4@P5&#I0@1PZP('4.O"!!#L`@3`ZP
M('\.N"!"#KP@00[`($D.L"!/#KP@00[`($D.L"!:"@X40<,.$$'&#@Q!QPX(
M0<4.!$L+8PH.%$/##A!!Q@X,0<<."$'%#@1'"P```#P```#@!0``I)/___P#
M````00X(A0)!#@R'`T$.$(8$3`X4@P5##D`#N`,*#A1'PPX00<8.#$''#@A!
MQ0X$10L8````(`8``&27__]A`````$T.(`)&"@X$10L`)````#P&``"XE___
M10````!!#@B#`DX.(%4.)$H.*$(.+$(.,````+````!D!@``X)?__Z$!````
M00X(A0)!#@R'`T$.$(8$00X4@P5'#`.4@`1.#01##L"`!%X.Q(`$0@[(@`1"
M#LR`!$$.T(`$`D,.P(`$4`[$@`1$#LB`!$0.S(`$00[0@`1+#L"`!$P.Q(`$
M10[(@`1!#LR`!$$.T(`$20[`@`0"6@H.%$'##A!!Q@X,0<<."$'%#@1("P)'
M"@[,@`1'#M"`!$8+4PH.S(`$1P[0@`1&"P```"@````8!P``W)C__RT`````
M00X(@P).#A!)#AQ!#B!)#A!)#@A!PPX$````7````$0'``#@F/__Q0````!!
M#@B%`DP.#(<#00X0A@1!#A2#!4,.0'X*#A1#PPX00<8.#$''#@A!Q0X$2@M#
M#DQ!#E!G#D1)#DA!#DQ'#E!!#E1"#EA"#EQ!#F!-#D``F`(``*0'``!0F?__
M6@<```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.H`("Y@ZL`D$.L`))#J`"50ZL
M`D$.L`)-#J`"0PZL`D$.L`)/#J`"8`ZL`D<.L`)!#K0"0@ZX`D(.O`)!#L`"
M4`Z@`@)`#JP"00ZP`DL.H`)_#JP"00ZP`D<.K`)$#K`":`ZT`D$.N`)+#KP"
M1P[``D,.Q`)"#L@"0@[,`D$.T`))#J@"10ZL`D$.L`))#J`"60ZH`D$.K`)$
M#K`"2PZ@`D<.K`)$#K`"1@ZT`D<.N`)*#KP"0@[``DD.H`):"@X40\,.$$'&
M#@Q!QPX(0<4.!$@+0PZL`D0.L`)+#J`"`ED.K`)!#K`"6`Z@`DL.J`)!#JP"
M1@ZP`DT.H`)+#JP"1`ZP`DL.H`)(#J@"1PZL`DT.L`))#J`"`FH.I`)!#J@"
M2@ZL`D0.L`)!#K0"0@ZX`D(.O`)!#L`"3PZ@`E\.K`)!#K`"00ZT`D$.N`)$
M#KP"1`[``D0.Q`)"#L@"0@[,`D$.T`))#J`"0PZH`D4.K`)!#K`"20Z@`D@.
MK`)$#K`"70Z@`@)&#JP"2`ZP`DL.H`);#JP"00ZP`DL.H`),"@ZH`D$.K`)$
M#K`"1@ZT`E(+0PZL`D$.L`))#J`"80H.%$/##A!!Q@X,0<<."$'%#@1,"UL.
MJ`)"#JP"1`ZP`DD.H`)F#J0"1`ZH`D$.K`)%#K`"30ZD`D(.J`)(#JP"10ZP
M`DT.H`)P#J0"3PZH`D$.K`)!#K`"30ZD`D(.J`)(#JP"10ZP`DD.H`)8#J0"
M1PZH`D0.K`)$#K`"00ZT`D(.N`)"#KP"00[``DD.H`)7#JP"00ZP`DT.H`),
M#J@"1PZL`DD.L`)-#J`":`ZL`D<.L`(```#,````0`H``!2>__\>`@```$$.
M"(4"00X,AP-!#A"&!$$.%(,%3@XP`DL.-$(..$$./$$.0$L.,$<.-$<..$4.
M/$,.0$X.,%(.-$(..$$./$,.0$L.,%P.-$$..$4./$,.0$D.,$,.-$@..$$.
M/$,.0$\.-$$..$$./$,.0%T.,$\..$4./$$.0$P.,&(*#A1!PPX00<8.#$''
M#@A!Q0X$2`M#"@X\1@Y`40XP5`X\1PY`2PMS#CA!#CQ##D!)#C!3"@XT1PXX
M0@X\1PY`1@L`:````!`+``!DG___R0````!!#@B'`D$.#(8#00X0@P1.#B`"
M3@H.$$'##@Q!Q@X(0<<.!$8+0PXL00XP20XL00XH0@XL00XP6@XD2`XH00XL
M00XP20X@5`H.$$/##@Q!Q@X(0<<.!$4+````1````'P+``#X<O__5@(```!$
M#`$`21`%`G4`01`'`G5\1!`&`G5X$`,"=71,#P-U<`8#;P$*P0P!`$'#0<9!
MQT'%0PP$!$$+(````,0+``"`G___0@````!!#@B#`DX.'$(.(&\."$'##@0`
M3````.@+``"LG___EP$```!!#@B%`D$.#(<#00X0A@1,#A2#!4,.,`+P"@X4
M0<,.$$'&#@Q!QPX(0<4.!$H+`D,.-$,..$4./$$.0%(.,``\````.`P``/R@
M____`0```$$."(4"00X,AP-!#A"&!$P.%(,%0PXP`QX!"@X40<,.$$'&#@Q!
MQPX(0<4.!$P+$````'@,``"[HO__!``````````0````C`P``*NB__\$````
M`````!````"@#```FZ+__P0`````````(````+0,``"0HO__*0````!-#A!&
M#A1$#AA$#AQ$#B!)#@0`$````-@,``"5HO__!``````````8````[`P``(BB
M__\5`````$$."$$.!$T.$```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#`(P``
M<",```$```#S`@```0```/X"```=````D@0```P`````(```#0```%A1```9
M````U+T``!L````$````&@```-B]```<````!````/7^_V\T`@``!0```&P)
M```&````?`,```H```"U!```"P```!`````5``````````,```#DO@```@``
M``@````4````$0```!<```"X$0``$0```(`/```2````.`(``!,````(````
M'@````@```#[__]O`0``"/[__V_@#@``____;P$```#P__]O(@X``/K__V\&
M`````````````````````````````````````````````````````````-R]
M`````````````#8@````````````````````````````````````````````
M```````````````````````@2@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`(`````````3````*4$%2+G!M"@````#L8@``1T-#.B`H1TY5
M*2`Q,RXR+C$@,C`R,S`X,#$``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M```````````````````````````````````````````````````````+````
M`0````(```"T`0``M`$``!,```````````````$`````````$P````<````"
M````R`$``,@!```D```````````````$`````````"8````'`````@```.P!
M``#L`0``*```````````````!``````````Y````!P````(````4`@``%`(`
M`"````````````````0`````````1P```/;__V\"````-`(``#0"``!(`0``
M!@`````````$````!````%$````+`````@```'P#``!\`P``\`4```<````!
M````!````!````!9`````P````(```!L"0``;`D``+4$``````````````$`
M````````80```/___V\"````(@X``"(.``"^````!@`````````"`````@``
M`&X```#^__]O`@```.`.``#@#@``H`````<````!````!`````````!]````
M"0````(```"`#P``@`\``#@"```&``````````0````(````A@````D```!"
M````N!$``+@1```(````!@```!8````$````"````(\````!````!@`````@
M````(```(```````````````!`````````"*`````0````8````@(```("``
M`"```````````````!`````$````E0````$````&````0"```$`@```5,0``
M```````````0`````````)L````!````!@```%A1``!840``%```````````
M````!`````````"A`````0````(`````8````&```(!``````````````!``
M````````J0````$````"````@*```("@```<`0`````````````$````````
M`+<````!`````@```)RA``"<H0``-`T`````````````!`````````#!````
M#@````,```#4O0``U+T```0```````````````0````$````S0````\````#
M````V+T``-B]```$```````````````$````!````-D````&`````P```-R]
M``#<O0``"`$```<`````````!`````@```#B`````0````,```#DO@``Y+X`
M`!P!``````````````0````$````YP````$````#`````,````#````8````
M```````````$`````````.T````(`````P```!C````8P```%```````````
M````!`````````#R`````0```#``````````&,```!L```````````````$`
M```!`````0````,``````````````#/```#[```````````````!````````
!````
